@@ -25,6 +25,14 @@ module Fog
         @masks ||= {}
       end
 
+      # Defines a new attribute
+      # @param [Symbol] name attribute name
+      # @param [Hash] options (see {Default#initialize})
+      # @option options [Symbol, ::String] :type attribute type (see {Attributes})
+      # @option options [Symbol] :squash
+      # @option options [::Array] :aliases
+      # @option options [Object] :default
+      # @option options [Object] :as
       def attribute(name, options = {})
         type = options.fetch(:type, "default").to_s.capitalize
         Fog::Attributes.const_get(type).new(self, name, options)
@@ -125,9 +133,13 @@ module Fog
         send("#{identity_name}=", new_identity)
       end
 
+      # Merges attributes into self
+      # @note Ignored attributes are not merged (see {ClassMethods.ignored_attributes})
+      # @return [self]
       def merge_attributes(new_attributes = {})
         new_attributes.each_pair do |key, value|
           next if self.class.ignored_attributes.include?(key)
+
           if self.class.aliases[key]
             send("#{self.class.aliases[key]}=", value)
           elsif self.respond_to?("#{key}=", true)
@@ -139,6 +151,18 @@ module Fog
         self
       end
 
+      # Filters attributes by selected attribute names
+      # @note In some cases we want to easily get subset of model attributes
+      # @note Hash#slice requires Ruby >= 2.5.0
+      # @param [Symbol] selected attribute names
+      # @return [Hash] new hash with selected attributes
+      def filter_attributes(*selected)
+        filtered = attributes.select { |a, _| selected.include?(a) }
+
+        # we should use getters instead of direct accessing attributes hash
+        filtered.each_key { |k| filtered[k] = send(k) }
+      end
+
       # Returns true if a remote resource has been assigned an
       # identity and we can assume it has been persisted.
       #
@@ -166,14 +190,15 @@ module Fog
         if missing.length == 1
           raise(ArgumentError, "#{missing.first} is required for this operation")
         elsif missing.any?
-          raise(ArgumentError, "#{missing[0...-1].join(", ")} and #{missing[-1]} are required for this operation")
+          raise(ArgumentError, "#{missing[0...-1].join(', ')} and #{missing[-1]} are required for this operation")
         end
       end
 
       def requires_one(*args)
         missing = missing_attributes(args)
         return unless missing.length == args.length
-        raise(ArgumentError, "#{missing[0...-1].join(", ")} or #{missing[-1]} are required for this operation")
+
+        raise(ArgumentError, "#{missing[0...-1].join(', ')} or #{missing[-1]} are required for this operation")
       end
 
       protected
@@ -181,7 +206,7 @@ module Fog
       def missing_attributes(args)
         missing = []
         ([:service] | args).each do |arg|
-          missing << arg unless send("#{arg}") || attributes.key?(arg)
+          missing << arg unless send(arg.to_s) || attributes.key?(arg)
         end
         missing
       end
