@@ -8,9 +8,10 @@ module Fog
       if duration > timeout
         raise Errors::TimeoutError, "The specified wait_for timeout (#{timeout} seconds) was exceeded"
       end
+
       sleep(interval.respond_to?(:call) ? interval.call(retries += 1).to_f : interval.to_f)
       duration = Time.now - start
     end
-    { :duration => duration }
+    { duration: duration }
   end
 end
