@@ -1,8 +1,8 @@
 begin
   # Use mime/types/columnar if available, for reduced memory usage
-  require 'mime/types/columnar'
+  require "mime/types/columnar"
 rescue LoadError
-  require 'mime/types'
+  require "mime/types"
 end
 
 module Fog
@@ -24,18 +24,18 @@ module Fog
       if body.respond_to?(:encoding)
         original_encoding = body.encoding
         body = body.dup if body.frozen?
-        body = body.force_encoding('BINARY')
+        body = body.force_encoding("BINARY")
       end
 
       size = if body.respond_to?(:bytesize)
-        body.bytesize
-      elsif body.respond_to?(:size)
-        body.size
-      elsif body.respond_to?(:stat)
-        body.stat.size
-      else
-        0
-      end
+               body.bytesize
+             elsif body.respond_to?(:size)
+               body.size
+             elsif body.respond_to?(:stat)
+               body.stat.size
+             else
+               0
+             end
 
       if body.respond_to?(:encoding)
         body.force_encoding(original_encoding)
@@ -55,11 +55,10 @@ module Fog
 
     def self.parse_data(data)
       {
-        :body     => data,
-        :headers  => {
-          "Content-Length"  => get_body_size(data),
-          "Content-Type"    => get_content_type(data)
-          # "Content-MD5" => Base64.encode64(Digest::MD5.digest(metadata[:body])).strip
+        body: data,
+        headers: {
+          "Content-Length" => get_body_size(data),
+          "Content-Type" => get_content_type(data)
         }
       }
     end
