@@ -4,7 +4,7 @@ describe "Fog::WhitelistKeys" do
   describe ".whitelist" do
     describe "when other keys are present" do
       it "returns Hash with only allowed keys" do
-        input = { :name => "name", :type => "type", :size => 80 }
+        input = { name: "name", type: "type", size: 80 }
         valid_keys = %w(name size)
 
         output = Fog::WhitelistKeys.whitelist(input, valid_keys)
@@ -16,7 +16,7 @@ describe "Fog::WhitelistKeys" do
 
     describe "when key is a Symbol" do
       it "returns a String" do
-        input = { :name => "name" }
+        input = { name: "name" }
         valid_keys = %w(name)
 
         output = Fog::WhitelistKeys.whitelist(input, valid_keys)
