@@ -22,14 +22,14 @@ describe Fog::CurrentMachine do
 
       (1..10).map do
         Thread.new do
-          Excon.stub({ :method => :get, :path => "/" }, { :body => "" })
+          Excon.stub({ method: :get, path: "/" }, { body: "" })
           Fog::CurrentMachine.ip_address
         end
       end.each(&:join)
     end
 
     it "should remove trailing endline characters" do
-      Excon.stub({ :method => :get, :path => "/" }, { :body => "192.168.0.1\n" })
+      Excon.stub({ method: :get, path: "/" }, { body: "192.168.0.1\n" })
       assert_equal "192.168.0.1", Fog::CurrentMachine.ip_address
     end
   end
