@@ -1,11 +1,6 @@
-if ENV["COVERAGE"]
-  require "coveralls"
-  require "simplecov"
-
-  SimpleCov.start do
-    add_filter "/spec/"
-  end
-end
+# Set home outside of real user
+require "tmpdir"
+ENV["HOME"] = Dir.mktmpdir("foghome")
 
 require "minitest/autorun"
 require "minitest/spec"
