@@ -2,7 +2,7 @@ require "spec_helper"
 
 describe "Fog#wait_for" do
   it "returns a Hash indicating the wait duration if successful" do
-    assert_equal({ :duration => 0 }, Fog.wait_for(1) { true })
+    assert_equal({ duration: 0 }, Fog.wait_for(1) { true })
   end
 
   it "raises if the wait timeout is exceeded" do
@@ -14,7 +14,7 @@ describe "Fog#wait_for" do
   it "does not raise if successful when the wait timeout is exceeded" do
     timeout = 2
     i = 0
-    ret = Fog.wait_for(timeout) { i = i + 1; i > 2 }
+    ret = Fog.wait_for(timeout) { i += 1; i > 2 }
     assert_operator(ret[:duration], :>, timeout)
   end
 
